@@ -38,7 +38,7 @@ import org.bluray.bdplus.Status;
 import org.bluray.net.BDLocator;
 import org.bluray.system.RegisterAccess;
 import org.bluray.ti.DiscManager;
-import org.bluray.ti.TitleImpl;
+import org.bluray.ti.Title;
 import org.bluray.ti.selection.TitleContext;
 import org.bluray.ui.event.HRcEvent;
 import org.dvb.event.EventManager;
@@ -353,6 +353,13 @@ public class Libbluray {
         loadAdapter(System.getProperty("org.videolan.loader.adapter"));
         loadAdapter(pkg);
 
+        /* get title infos */
+        titleInfos = getTitleInfosN(nativePointer);
+        if (titleInfos == null) {
+            /* this is fatal */
+            throw new Error("getTitleInfos() failed");
+        }
+
         booted = true;
     }
 
@@ -388,9 +395,7 @@ public class Libbluray {
             System.err.println("shutdown() failed: " + e + "\n" + Logger.dumpStack(e));
         }
         nativePointer = 0;
-        synchronized (titleInfosLock) {
-            titleInfos = null;
-        }
+        titleInfos = null;
         synchronized (bdjoFilesLock) {
             bdjoFiles = null;
         }
@@ -430,20 +435,11 @@ public class Libbluray {
 
     /* used by javax/tv/service/SIManagerImpl */
     public static int numTitles() {
-        synchronized (titleInfosLock) {
-            if (titleInfos == null) {
-                titleInfos = getTitleInfosN(nativePointer);
-                if (titleInfos == null) {
-                    return -1;
-                }
-            }
-            return titleInfos.length - 2;
-        }
+        return titleInfos.length - 2;
     }
 
     /* used by org/bluray/ti/TitleImpl */
     public static TitleInfo getTitleInfo(int titleNum) {
-        synchronized (titleInfosLock) {
             int numTitles = numTitles();
             if (numTitles < 0)
                 return null;
@@ -456,7 +452,6 @@ public class Libbluray {
                 throw new IllegalArgumentException();
 
             return titleInfos[titleNum];
-        }
     }
 
     /* used by org/bluray/ti/PlayListImpl */
@@ -634,17 +629,15 @@ public class Libbluray {
      */
 
     private static boolean startTitle(int titleNumber) {
-
-        TitleContext titleContext = null;
         try {
             BDLocator locator = new BDLocator(null, titleNumber, -1);
-            TitleImpl title   = (TitleImpl)SIManager.createInstance().getService(locator);
+            Title title = (Title)SIManager.createInstance().getService(locator);
             if (title == null) {
                 System.err.println("startTitle() failed: title " + titleNumber + " not found");
                 return false;
             }
 
-            titleContext = (TitleContext)ServiceContextFactory.getInstance().getServiceContext(null);
+            TitleContext titleContext = (TitleContext)ServiceContextFactory.getInstance().getServiceContext(null);
             titleContext.start(title, true);
             return true;
 
@@ -655,9 +648,8 @@ public class Libbluray {
     }
 
     private static boolean stopTitle(boolean shutdown) {
-        TitleContext titleContext = null;
         try {
-            titleContext = (TitleContext)ServiceContextFactory.getInstance().getServiceContext(null);
+            TitleContext titleContext = (TitleContext)ServiceContextFactory.getInstance().getServiceContext(null);
             if (shutdown) {
                 titleContext.destroy();
             } else {
@@ -831,6 +823,5 @@ public class Libbluray {
                                               int x0, int y0, int x1, int y1);
 
     private static long nativePointer = 0;
-    private static Object titleInfosLock = new Object();
     private static TitleInfo[] titleInfos = null;
 }
