@@ -634,10 +634,22 @@ static void _render_composition_object(GRAPHICS_CONTROLLER *gc,
 
         gc->overlay_proc(gc->overlay_proc_handle, &ov);
 
-        bd_refcnt_dec(cropped_img);
+        refcnt_dec(cropped_img);
     }
 }
 
+/* exported */
+const void *bd_refcnt_inc(const void *obj)
+{
+    return refcnt_inc(obj);
+}
+
+/* exported */
+void bd_refcnt_dec(const void *obj)
+{
+    refcnt_dec(obj);
+}
+
 static void _render_rle(GRAPHICS_CONTROLLER *gc,
                         int64_t pts,
                         BD_PG_RLE_ELEM *img,
@@ -747,7 +759,7 @@ static void _gc_reset(GRAPHICS_CONTROLLER *gc)
 /*
  * register hook
  */
-static void _process_psr_event(void *handle, BD_PSR_EVENT *ev)
+static void _process_psr_event(void *handle, const BD_PSR_EVENT *ev)
 {
     GRAPHICS_CONTROLLER *gc = (GRAPHICS_CONTROLLER *)handle;
 
@@ -2048,7 +2060,11 @@ int gc_run(GRAPHICS_CONTROLLER *gc, gc_ctrl_e ctrl, uint32_t param, GC_NAV_CMDS
         case GC_CTRL_MOUSE_MOVE:
             result = _mouse_move(gc, param >> 16, param & 0xffff, cmds);
             break;
-
+#ifndef __COVERITY__
+        /* no "default:" :
+         * this chunk is used to trigger a warning when a new enum value is added,
+         * but not handled here.
+         */
         case GC_CTRL_RESET:
         case GC_CTRL_PG_RESET:
         case GC_CTRL_PG_UPDATE:
@@ -2056,6 +2072,7 @@ int gc_run(GRAPHICS_CONTROLLER *gc, gc_ctrl_e ctrl, uint32_t param, GC_NAV_CMDS
         case GC_CTRL_STYLE_SELECT:
             /* already handled */
             break;
+#endif
     }
 
     if (cmds) {
