@@ -1,6 +1,6 @@
 /*
  * This file is part of libbluray
- * Copyright (C) 2010-2014  Petri Hintukainen <phintuka@users.sourceforge.net>
+ * Copyright (C) 2010-2017  Petri Hintukainen <phintuka@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -56,6 +56,7 @@ struct hdmv_vm_s {
     HDMV_EVENT     event[5];      /* pending events to return */
 
     NV_TIMER       nv_timer;      /* navigation timer */
+    uint64_t       rand;          /* RAND state */
 
     /* movie objects */
     MOBJ_OBJECTS  *movie_objects; /* disc movie objects */
@@ -300,6 +301,28 @@ static void _fetch_operands(HDMV_VM *p, MOBJ_CMD *cmd, uint32_t *dst, uint32_t *
  * event queue
  */
 
+const char *hdmv_event_str(hdmv_event_e event)
+{
+    switch (event) {
+#define EVENT_ENTRY(e) case e : return #e
+        EVENT_ENTRY(HDMV_EVENT_NONE);
+        EVENT_ENTRY(HDMV_EVENT_END);
+        EVENT_ENTRY(HDMV_EVENT_IG_END);
+        EVENT_ENTRY(HDMV_EVENT_TITLE);
+        EVENT_ENTRY(HDMV_EVENT_PLAY_PL);
+        EVENT_ENTRY(HDMV_EVENT_PLAY_PI);
+        EVENT_ENTRY(HDMV_EVENT_PLAY_PM);
+        EVENT_ENTRY(HDMV_EVENT_PLAY_STOP);
+        EVENT_ENTRY(HDMV_EVENT_STILL);
+        EVENT_ENTRY(HDMV_EVENT_SET_BUTTON_PAGE);
+        EVENT_ENTRY(HDMV_EVENT_ENABLE_BUTTON);
+        EVENT_ENTRY(HDMV_EVENT_DISABLE_BUTTON);
+        EVENT_ENTRY(HDMV_EVENT_POPUP_OFF);
+#undef EVENT_ENTRY
+    }
+    return "???";
+}
+
 static int _get_event(HDMV_VM *p, HDMV_EVENT *ev)
 {
     if (p->event[0].event != HDMV_EVENT_NONE) {
@@ -324,7 +347,7 @@ static int _queue_event(HDMV_VM *p, hdmv_event_e event, uint32_t param)
         }
     }
 
-    BD_DEBUG(DBG_HDMV|DBG_CRIT, "_queue_event(%d, %d): queue overflow !\n", event, param);
+    BD_DEBUG(DBG_HDMV|DBG_CRIT, "_queue_event(%d:%s, %d): queue overflow !\n", event, hdmv_event_str(event), param);
     return -1;
 }
 
@@ -353,6 +376,11 @@ HDMV_VM *hdmv_vm_init(struct bd_disc *disc, BD_REGISTERS *regs,
     p->num_titles      = num_titles;
     p->have_top_menu   = top_menu_available;
     p->have_first_play = first_play_available;
+#ifdef DEBUG
+    p->rand = 1;
+#else
+    p->rand = time(NULL);
+#endif
 
     bd_mutex_init(&p->mutex);
 
@@ -982,9 +1010,16 @@ static void _hdmv_trace_res(uint32_t new_src, uint32_t new_dst, uint32_t orig_sr
 
 #define SWAP_u32(a, b) do { uint32_t tmp = a; a = b; b = tmp; } while(0)
 
-static inline uint32_t RAND_u32(uint32_t range)
+static inline uint32_t RAND_u32(HDMV_VM *p, uint32_t range)
 {
-  return range > 0 ? rand() % range + 1 : 0;
+    p->rand = p->rand * UINT64_C(6364136223846793005) + UINT64_C(1);
+
+    if (range == 0) {
+      BD_DEBUG(DBG_HDMV|DBG_CRIT, "RAND_u32: invalid range (0)\n");
+      return 1;
+    }
+
+    return ((uint32_t)(p->rand >> 32)) % range + 1;
 }
 
 static inline uint32_t ADD_u32(uint32_t a, uint32_t b)
@@ -1058,9 +1093,9 @@ static int _hdmv_step(HDMV_VM *p)
                         case INSN_PLAY_PL:      _play_at(p, dst,  -1,  -1); break;
                         case INSN_PLAY_PL_PI:   _play_at(p, dst, src,  -1); break;
                         case INSN_PLAY_PL_PM:   _play_at(p, dst,  -1, src); break;
-                        case INSN_TERMINATE_PL: _play_stop(p);              break;
                         case INSN_LINK_PI:      _play_at(p,  -1, dst,  -1); break;
                         case INSN_LINK_MK:      _play_at(p,  -1,  -1, dst); break;
+                        case INSN_TERMINATE_PL: if (!_play_stop(p)) { inc_pc = 0; } break;
                         default:
                             BD_DEBUG(DBG_HDMV|DBG_CRIT, "unknown BRANCH/PLAY option %d in opcode 0x%08x\n",
                                      insn->branch_opt, *(uint32_t*)insn);
@@ -1111,7 +1146,7 @@ static int _hdmv_step(HDMV_VM *p)
                         case INSN_MOD:    dst  = src > 0   ? dst % src : 0xffffffff; break;
                         case INSN_ADD:    dst  = ADD_u32(src, dst);  break;
                         case INSN_MUL:    dst  = MUL_u32(dst, src);  break;
-                        case INSN_RND:    dst  = RAND_u32(src);      break;
+                        case INSN_RND:    dst  = RAND_u32(p, src);   break;
                         case INSN_AND:    dst &= src;         break;
                         case INSN_OR:     dst |= src;         break;
                         case INSN_XOR:    dst ^= src;         break;
