@@ -1,6 +1,6 @@
 /*
  * This file is part of libbluray
- * Copyright (C) 2010-2014  Petri Hintukainen <phintuka@users.sourceforge.net>
+ * Copyright (C) 2010-2017  Petri Hintukainen <phintuka@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -58,6 +58,10 @@ typedef enum {
     PSR_3D_STATUS        = 22,
     PSR_DISPLAY_CAP      = 23,
     PSR_3D_CAP           = 24,
+    PSR_UHD_CAP          = 25,
+    PSR_UHD_DISPLAY_CAP  = 26,
+    PSR_UHD_HDR_PREFER   = 27,
+    PSR_UHD_SDR_CONV_PREFER = 28,
     PSR_VIDEO_CAP        = 29,
     PSR_TEXT_CAP         = 30, /* text subtitles */
     PSR_PROFILE_VERSION  = 31, /* player profile and version */
@@ -251,7 +255,7 @@ typedef struct {
  * @param callback  callback function pointer
  * @param handle  application-specific handle that is provided to callback function as first parameter
  */
-void bd_psr_register_cb(BD_REGISTERS *, void (*callback)(void*,BD_PSR_EVENT*), void *cb_handle);
+void bd_psr_register_cb(BD_REGISTERS *, void (*callback)(void*,const BD_PSR_EVENT*), void *cb_handle);
 
 /**
  *
@@ -261,9 +265,21 @@ void bd_psr_register_cb(BD_REGISTERS *, void (*callback)(void*,BD_PSR_EVENT*), v
  * @param callback  callback function to unregister
  * @param handle  application-specific handle that was used when callback was registered
  */
-void bd_psr_unregister_cb(BD_REGISTERS *, void (*callback)(void*,BD_PSR_EVENT*), void *cb_handle);
+void bd_psr_unregister_cb(BD_REGISTERS *, void (*callback)(void*,const BD_PSR_EVENT*), void *cb_handle);
 
-BD_PRIVATE void psr_init_3D(BD_REGISTERS *, int initial_mode);
+BD_PRIVATE int psr_init_3D(BD_REGISTERS *, int initial_mode, int force);
+
+/**
+ *
+ * Initialize registers for profile 6 (UHD) playback.
+ *
+ * Profiles 5 (3D) and 6 (UHD) can't be enabld at the same time.
+ *
+ * @param registers  BD_REGISTERS object
+ * @return 0 on success, -1 on error (invalid state)
+ *
+ */
+BD_PRIVATE int psr_init_UHD(BD_REGISTERS *, int force);
 
 
 /*
